@@ -208,6 +208,9 @@ QAbstractKineticScroller *scroller2 =ui.textEdit_2->property("kineticScroller").
 scroller2->setEnabled(true);
 #endif
 
+ QList<QWidget *> widgets = this->ui.centralwidget->findChildren<QWidget *>();
+for (int i=0;i<widgets.count();i++)
+     widgets.at(i)->installEventFilter(this);
 }
 
 void MainWindow::reload(){
@@ -234,6 +237,69 @@ QFile file2("/home/user/.tplayer-lists");
        drawlist();
 }
 
+
+
+bool MainWindow::eventFilter(QObject *obj, QEvent *event)
+{
+
+    if (event->type()==6){
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+
+
+        switch (keyEvent->key()) {
+        case Qt::Key_Right:
+        next();
+        return true;
+        break;
+
+
+        case Qt::Key_Left:
+        prev();
+       return true;
+        break;
+
+        case Qt::Key_Space:
+        play_pause();
+        return true;
+        break;
+
+        case Qt::Key_Z:
+        click1();
+        return true;
+        break;
+
+        case Qt::Key_X:
+        click2();
+       return true;
+        break;
+
+        case Qt::Key_C:
+        click3();
+        return true;
+        break;
+
+        case Qt::Key_V:
+        click4();
+        return true;
+        break;
+
+        case Qt::Key_B:
+        click5();
+        return true;
+        break;
+
+        default: return QObject::eventFilter(obj, event); break;
+
+
+
+        }
+
+    } else {
+        // standard event processing
+        return QObject::eventFilter(obj, event);
+    }
+}
+
 void MainWindow::keyPressEvent(QKeyEvent* event)
   {
 
@@ -249,7 +315,10 @@ device->setVolume(device->volume()+0.1);
           event->accept();
           break;
 
-      }
+     }
+
+
+
 
 
       QWidget::keyPressEvent(event);
@@ -335,7 +404,7 @@ scrobler=new last(tyu.at(4),tyu.at(5));
 }
             else{
                 scrobler=new last("","");
-                
+
             }
 
 file.close();
